summaryrefslogtreecommitdiffstats
path: root/Modules
diff options
context:
space:
mode:
authorNils Gladitz <n.gladitz@abberior-instruments.com>2017-08-02 14:03:01 (GMT)
committerNils Gladitz <nilsgladitz@gmail.com>2017-08-12 15:27:06 (GMT)
commita17ef5748abc8ef5d3117b5c6c8138ef1cdc9719 (patch)
tree4c41b4cffe894ff46f3b3c31036e3c9858b438f7 /Modules
parent611f162532e2abf634aa591df8b6739aa00172a6 (diff)
downloadCMake-a17ef5748abc8ef5d3117b5c6c8138ef1cdc9719.zip
CMake-a17ef5748abc8ef5d3117b5c6c8138ef1cdc9719.tar.gz
CMake-a17ef5748abc8ef5d3117b5c6c8138ef1cdc9719.tar.bz2
CPackDeb: Loosen filename requirement to allow for .ipk
The OPKG packaging system uses deb like package files with an .ipk extension. Allow the DEB generator to be used in that context.
Diffstat (limited to 'Modules')
-rw-r--r--Modules/CPackDeb.cmake7
1 files changed, 4 insertions, 3 deletions
diff --git a/Modules/CPackDeb.cmake b/Modules/CPackDeb.cmake
index daba7d5..85d564e 100644
--- a/Modules/CPackDeb.cmake
+++ b/Modules/CPackDeb.cmake
@@ -73,7 +73,8 @@
#
# <PackageName>_<VersionNumber>-<DebianRevisionNumber>_<DebianArchitecture>.deb
#
# Alternatively provided package file name must end with ``.deb`` suffix.
#
# .. note::
#
@@ -977,9 +978,9 @@ function(cpack_deb_prepare_package_vars)
else()
cmake_policy(PUSH)
cmake_policy(SET CMP0010 NEW)
- if(NOT CPACK_DEBIAN_FILE_NAME MATCHES ".*\\.deb")
+ if(NOT CPACK_DEBIAN_FILE_NAME MATCHES ".*\\.(deb|ipk)")
cmake_policy(POP)
- message(FATAL_ERROR "'${CPACK_DEBIAN_FILE_NAME}' is not a valid DEB package file name as it must end with '.deb'!")
+ message(FATAL_ERROR "'${CPACK_DEBIAN_FILE_NAME}' is not a valid DEB package file name as it must end with '.deb' or '.ipk'!")
endif()
cmake_policy(POP)
@@ -73,7 +73,8 @@
# <PackageName>_<VersionNumber>-<DebianRevisionNumber>_<DebianArchitecture>.deb
#
-# Alternatively provided package file name must end with ``.deb`` suffix.
+# Alternatively provided package file name must end
+# with either ``.deb`` or ``.ipk`` suffix.
#
# .. note::